% logistic map Lyapunov exponent with bifurcation diagram

clear all

a0 = 3.23;                     % initial parameter value
a1 = 3.92;                     % final parameter value
N = 999;                       % number of parameter values
Niter = 1000;                  % number of iterates

da = (a1-a0)/(N-1);
aa = a0:da:a1;

% determine the map iterates

x = zeros(Niter,N);
for i=1:N
    x(1,i) = 0.3;
    for j=1:Niter-1
        x(j+1,i) = aa(i)*x(j,i)*(1-x(j,i));
    end
end    

% plot the exponents

le = zeros(N,1);
for i=1:N
    le(i) = sum(log(abs(aa(i)*(1-2*x(:,i)))))/Niter;
end    

lemax = max(le);
lemin = min(le);
figure(3)
subplot(2,1,1)
for i=1:N
    plot(aa(i)*ones(200,1),x(Niter-199:Niter,i),'b.','MarkerSize',2)
    hold on
end    
xlabel a, ylabel x
axis([a0 a1 0 1]), set(gca,'xtick',a0:(a1-a0)/10:a1,'ytick',0:.2:1)
hold off
subplot(2,1,2)
plot(aa,le,'b-',aa,zeros(N,1),'r-')
xlabel a, ylabel L
axis([a0 a1 lemin-.1 lemax+.1]) 
set(gca,'xtick',a0:(a1-a0)/10:a1,'ytick',lemin:(lemax-lemin)/5:lemax)
